@@ -16,6 +16,8 @@ import (
 	"git.sr.ht/~emersion/hut/srht/listssrht"
 )
 
+const archiveFilename = "archive.mbox"
+
 type ListsExporter struct {
 	client *gqlclient.Client
 	http   *http.Client
@@ -39,9 +41,10 @@ func NewListsExporter(client *gqlclient.Client, http *http.Client) *ListsExporte
 // export (i.e. the ones filled in by the GraphQL query)
 type MailingListInfo struct {
 	Info
-	Description *string  `json:"description"`
-	PermitMime  []string `json:"permitMime"`
-	RejectMime  []string `json:"rejectMime"`
+	Description *string              `json:"description"`
+	Visibility  listssrht.Visibility `json:"visibility"`
+	PermitMime  []string             `json:"permitMime"`
+	RejectMime  []string             `json:"rejectMime"`
 }
 
 func (ex *ListsExporter) Export(ctx context.Context, dir string) error {
@@ -60,7 +63,7 @@ func (ex *ListsExporter) Export(ctx context.Context, dir string) error {
 				return err
 			}
 
-			if err := ex.exportList(ctx, list, base); err != nil {
+			if err := ex.exportList(ctx, &list, base); err != nil {
 				var pe partialError
 				if errors.As(err, &pe) {
 					ret = err
@@ -79,7 +82,15 @@ func (ex *ListsExporter) Export(ctx context.Context, dir string) error {
 	return ret
 }
 
-func (ex *ListsExporter) exportList(ctx context.Context, list listssrht.MailingList, base string) error {
+func (ex *ListsExporter) ExportResource(ctx context.Context, dir, owner, resource string) error {
+	user, err := listssrht.ExportMailingList(ex.client, ctx, owner, resource)
+	if err != nil {
+		return err
+	}
+	return ex.exportList(ctx, user.List, dir)
+}
+
+func (ex *ListsExporter) exportList(ctx context.Context, list *listssrht.MailingList, base string) error {
 	infoPath := path.Join(base, infoFilename)
 	if _, err := os.Stat(infoPath); err == nil {
 		log.Printf("\tSkipping %s (already exists)", list.Name)
@@ -103,7 +114,7 @@ func (ex *ListsExporter) exportList(ctx context.Context, list listssrht.MailingL
 			list.Name, resp.StatusCode)}
 	}
 
-	archive, err := os.Create(path.Join(base, "archive.mbox"))
+	archive, err := os.Create(path.Join(base, archiveFilename))
 	if err != nil {
 		return err
 	}
@@ -118,6 +129,7 @@ func (ex *ListsExporter) exportList(ctx context.Context, list listssrht.MailingL
 			Name:    list.Name,
 		},
 		Description: list.Description,
+		Visibility:  list.Visibility,
 		PermitMime:  list.PermitMime,
 		RejectMime:  list.RejectMime,
 	}
@@ -127,3 +139,42 @@ func (ex *ListsExporter) exportList(ctx context.Context, list listssrht.MailingL
 
 	return nil
 }
+
+func (ex *ListsExporter) ImportResource(ctx context.Context, dir string) error {
+	var info MailingListInfo
+	if err := readJSON(path.Join(dir, infoFilename), &info); err != nil {
+		return err
+	}
+
+	return ex.importList(ctx, &info, dir)
+}
+
+func (ex *ListsExporter) importList(ctx context.Context, list *MailingListInfo, base string) error {
+	l, err := listssrht.CreateMailingList(ex.client, ctx, list.Name, list.Description, list.Visibility)
+	if err != nil {
+		return fmt.Errorf("failed to create mailing list: %v", err)
+	}
+
+	if _, err := listssrht.UpdateMailingList(ex.client, ctx, l.Id, listssrht.MailingListInput{
+		PermitMime: list.PermitMime,
+		RejectMime: list.RejectMime,
+	}); err != nil {
+		return fmt.Errorf("failed to update mailing list: %v", err)
+	}
+
+	archive, err := os.Open(path.Join(base, archiveFilename))
+	if err != nil {
+		return err
+	}
+	defer archive.Close()
+
+	if _, err := listssrht.ImportMailingListSpool(ex.client, ctx, l.Id, gqlclient.Upload{
+		Filename: archiveFilename,
+		MIMEType: "application/mbox",
+		Body:     archive,
+	}); err != nil {
+		return fmt.Errorf("failed to import mailing list emails: %v", err)
+	}
+
+	return nil
+}
